sqlobject.tests.test_distinct module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_distinct module

class `sqlobject.tests.test_distinct.` `Distinct1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = distinct1
  property `n`
  `q` = distinct1
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_distinct.Distinct1`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'distinct1'

class `sqlobject.tests.test_distinct.` `Distinct2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = distinct2
  property `other`
  property `otherID`
  `q` = distinct2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_distinct.Distinct2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'distinct2'

`sqlobject.tests.test_distinct.` `count`(select)

`sqlobject.tests.test_distinct.` `test_distinct`()